==> tutti-ui-swing-1.0-sources.jar: fr/ifremer/tutti/ui/swing/content/protocol/ImportProtocolCaracteristicAction.java <==
package fr.ifremer.tutti.ui.swing.content.protocol;

/*
 * #%L
 * Tutti :: UI
 * $Id: ImportProtocolCaracteristicAction.java 389 2013-02-11 08:14:47Z tchemit $
 * $HeadURL: http://svn.forge.codelutin.com/svn/tutti/tags/tutti-1.0/tutti-ui-swing/src/main/java/fr/ifremer/tutti/ui/swing/content/protocol/ImportProtocolCaracteristicAction.java $
 * %%
 * Copyright (C) 2012 - 2013 Ifremer
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import fr.ifremer.tutti.persistence.entities.protocol.TuttiProtocol;
import fr.ifremer.tutti.service.protocol.TuttiProtocolImportExportService;
import fr.ifremer.tutti.ui.swing.AbstractTuttiAction;
import fr.ifremer.tutti.ui.swing.util.TuttiUIUtil;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import java.awt.event.ActionEvent;
import java.io.File;

import static org.nuiton.i18n.I18n._;

/**
 * To import protocol caracteristics.
 *
 * @author tchemit <chemit@codelutin.com>
 * @since 1.0
 */
public class ImportProtocolCaracteristicAction extends AbstractTuttiAction<EditProtocolUIModel, EditProtocolUI, EditProtocolUIHandler> {

    private static final long serialVersionUID = 1L;

    /** Logger. */
    private static final Log log =
            LogFactory.getLog(ImportProtocolCaracteristicAction.class);

    private File file;

    public ImportProtocolCaracteristicAction(EditProtocolUIHandler handler) {
        super(handler,
              "importProtocolCaracteristic",
              "import",
              _("tutti.action.importProtocolCaracteristic"),
              _("tutti.action.importProtocolCaracteristic.tip"),
              true
        );
    }

    @Override
    protected boolean prepareAction(ActionEvent event) {

        // choose file to import
        file = TuttiUIUtil.chooseFile(
                getContext().getMainUI(),
                _("tutti.title.choose.protocolCaracteristicImportFile"),
                _("tutti.action.chooseProtocolCaracteristicFile"),
                null,
                "^.*\\.csv", _("tutti.file.csv")
        );
        boolean doAction = file != null;
        if (doAction) {
            super.prepareAction(event);
        }
        return doAction;
    }

    @Override
    protected void releaseAction(ActionEvent event) {
        super.releaseAction(event);
        file = null;
    }

    @Override
    protected void doAction(ActionEvent e) throws Exception {

        if (log.isInfoEnabled()) {
            log.info("Will import protocol caracteristic file: " + file);
        }

        EditProtocolUIHandler handler = getHandler();
        EditProtocolUIModel model = getModel();

        // bind to a protocol
        TuttiProtocol protocol = model.toBean();

        TuttiProtocolImportExportService service =
                getService(TuttiProtocolImportExportService.class);

        service.importProtocolCaracteristic(file,
                                            protocol,
                                            model.getAllCaracteristic());

        handler.addDoubleListListeners();

        try {
            // rebind to model
            model.fromBean(protocol);
        } finally {
            handler.removeDoubleListListeners();
        }

        sendMessage(
                _("tutti.flash.information.caracteristic.imported.in.protocol",
                  file));

    }
}

==> tutti-ui-swing-1.0.1-sources.jar: fr/ifremer/tutti/ui/swing/content/protocol/ImportProtocolCaracteristicAction.java <==
package fr.ifremer.tutti.ui.swing.content.protocol;

/*
 * #%L
 * Tutti :: UI
 * $Id: ImportProtocolCaracteristicAction.java 389 2013-02-11 08:14:47Z tchemit $
 * $HeadURL: http://svn.forge.codelutin.com/svn/tutti/tags/tutti-1.0.1/tutti-ui-swing/src/main/java/fr/ifremer/tutti/ui/swing/content/protocol/ImportProtocolCaracteristicAction.java $
 * %%
 * Copyright (C) 2012 - 2013 Ifremer
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import fr.ifremer.tutti.persistence.entities.protocol.TuttiProtocol;
import fr.ifremer.tutti.service.protocol.TuttiProtocolImportExportService;
import fr.ifremer.tutti.ui.swing.AbstractTuttiAction;
import fr.ifremer.tutti.ui.swing.util.TuttiUIUtil;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import java.awt.event.ActionEvent;
import java.io.File;

import static org.nuiton.i18n.I18n._;

/**
 * To import protocol caracteristics.
 *
 * @author tchemit <chemit@codelutin.com>
 * @since 1.0
 */
public class ImportProtocolCaracteristicAction extends AbstractTuttiAction<EditProtocolUIModel, EditProtocolUI, EditProtocolUIHandler> {

    private static final long serialVersionUID = 1L;

    /** Logger. */
    private static final Log log =
            LogFactory.getLog(ImportProtocolCaracteristicAction.class);

    private File file;

    public ImportProtocolCaracteristicAction(EditProtocolUIHandler handler) {
        super(handler,
              "importProtocolCaracteristic",
              "import",
              _("tutti.action.importProtocolCaracteristic"),
              _("tutti.action.importProtocolCaracteristic.tip"),
              true
        );
    }

    @Override
    protected boolean prepareAction(ActionEvent event) {

        // choose file to import
        file = TuttiUIUtil.chooseFile(
                getContext().getMainUI(),
                _("tutti.title.choose.protocolCaracteristicImportFile"),
                _("tutti.action.chooseProtocolCaracteristicFile"),
                null,
                "^.*\\.csv", _("tutti.file.csv")
        );
        boolean doAction = file != null;
        if (doAction) {
            super.prepareAction(event);
        }
        return doAction;
    }

    @Override
    protected void releaseAction(ActionEvent event) {
        super.releaseAction(event);
        file = null;
    }

    @Override
    protected void doAction(ActionEvent e) throws Exception {

        if (log.isInfoEnabled()) {
            log.info("Will import protocol caracteristic file: " + file);
        }

        EditProtocolUIHandler handler = getHandler();
        EditProtocolUIModel model = getModel();

        // bind to a protocol
        TuttiProtocol protocol = model.toBean();

        TuttiProtocolImportExportService service =
                getService(TuttiProtocolImportExportService.class);

        service.importProtocolCaracteristic(file,
                                            protocol,
                                            model.getAllCaracteristic());

        handler.addDoubleListListeners();

        try {
            // rebind to model
            model.fromBean(protocol);
        } finally {
            handler.removeDoubleListListeners();
        }

        sendMessage(
                _("tutti.flash.information.caracteristic.imported.in.protocol",
                  file));

    }
}
